@@ -3,6 +3,13 @@
 #Client is used with a 32 bit server to allow 64 bit python to use the 32 bit MagicDAQ Python API
 ###############################################
 
+###############################################
+#*** 32 Bit Server Debug ***
+###############################################
+
+# If you want to see output from the 32bit server in the main command window, set this variable False
+server_is_quite = True
+
 ###############################################
 #*** Imports ***
 ###############################################
@@ -28,7 +35,7 @@ class MagicDAQClient64Bit(Client64):
 
     def __init__(self):
         # Specify the name of the Python module to execute on the 32-bit server (i.e., 'my_server')
-        super(MagicDAQClient64Bit, self).__init__(module32='magicdaq_server_32bit')
+        super(MagicDAQClient64Bit, self).__init__(module32='magicdaq_server_32bit', quiet=server_is_quite)
 
     ###################################################
     # *** All PUBLIC DAQDevice Methods ***
